@@ -21,19 +21,19 @@
 #define FILTER_H
 
 // Qt
-#include <QtGui/QAction>
 #include <QtCore/QList>
 #include <QtCore/QObject>
 #include <QtCore/QStringList>
-#include <QtCore/QHash>
 #include <QtCore/QRegExp>
+#include <QtCore/QMultiHash>
 
 // Konsole
 #include "Character.h"
 
+class QAction;
+
 namespace Konsole
 {
-
 /**
  * A filter processes blocks of text looking for certain patterns (such as URLs or keywords from a list)
  * and marks the areas which match the filter's patterns as 'hotspots'.
@@ -70,70 +70,60 @@ public:
     class HotSpot
     {
     public:
-       /**
-        * Constructs a new hotspot which covers the area from (@p startLine,@p startColumn) to (@p endLine,@p endColumn)
-        * in a block of text.
-        */
-       HotSpot(int startLine , int startColumn , int endLine , int endColumn);
-       virtual ~HotSpot();
+        /**
+         * Constructs a new hotspot which covers the area from (@p startLine,@p startColumn) to (@p endLine,@p endColumn)
+         * in a block of text.
+         */
+        HotSpot(int startLine , int startColumn , int endLine , int endColumn);
+        virtual ~HotSpot();
 
-       enum Type
-       {
+        enum Type {
             // the type of the hotspot is not specified
             NotSpecified,
             // this hotspot represents a clickable link
             Link,
             // this hotspot represents a marker
             Marker
-       };
+        };
 
-       /** Returns the line when the hotspot area starts */
-       int startLine() const;
-       /** Returns the line where the hotspot area ends */
-       int endLine() const;
-       /** Returns the column on startLine() where the hotspot area starts */
-       int startColumn() const;
-       /** Returns the column on endLine() where the hotspot area ends */
-       int endColumn() const;
-       /**
-        * Returns the type of the hotspot.  This is usually used as a hint for views on how to represent
-        * the hotspot graphically.  eg.  Link hotspots are typically underlined when the user mouses over them
-        */
-       Type type() const;
-       /**
-        * Causes the action associated with a hotspot to be triggered.
-        *
-        * @param object The object which caused the hotspot to be triggered.  This is
-        * typically null ( in which case the default action should be performed ) or
-        * one of the objects from the actions() list.  In which case the associated
-        * action should be performed.
-        */
-       virtual void activate(QObject* object = 0) = 0;
-       /**
-        * Returns a list of actions associated with the hotspot which can be used in a
-        * menu or toolbar
-        */
-       virtual QList<QAction*> actions();
-
-       /**
-        * Returns the text of a tooltip to be shown when the mouse moves over the hotspot, or
-        * an empty string if there is no tooltip associated with this hotspot.
-        *
-        * The default implementation returns an empty string.
-        */
-       virtual QString tooltip() const;
+        /** Returns the line when the hotspot area starts */
+        int startLine() const;
+        /** Returns the line where the hotspot area ends */
+        int endLine() const;
+        /** Returns the column on startLine() where the hotspot area starts */
+        int startColumn() const;
+        /** Returns the column on endLine() where the hotspot area ends */
+        int endColumn() const;
+        /**
+         * Returns the type of the hotspot.  This is usually used as a hint for views on how to represent
+         * the hotspot graphically.  eg.  Link hotspots are typically underlined when the user mouses over them
+         */
+        Type type() const;
+        /**
+         * Causes the action associated with a hotspot to be triggered.
+         *
+         * @param object The object which caused the hotspot to be triggered.  This is
+         * typically null ( in which case the default action should be performed ) or
+         * one of the objects from the actions() list.  In which case the associated
+         * action should be performed.
+         */
+        virtual void activate(QObject* object = 0) = 0;
+        /**
+         * Returns a list of actions associated with the hotspot which can be used in a
+         * menu or toolbar
+         */
+        virtual QList<QAction*> actions();
 
     protected:
-       /** Sets the type of a hotspot.  This should only be set once */
-       void setType(Type type);
+        /** Sets the type of a hotspot.  This should only be set once */
+        void setType(Type type);
 
     private:
-       int    _startLine;
-       int    _startColumn;
-       int    _endLine;
-       int    _endColumn;
-       Type _type;
-
+        int    _startLine;
+        int    _startColumn;
+        int    _endLine;
+        int    _endColumn;
+        Type _type;
     };
 
     /** Constructs a new filter. */
@@ -175,7 +165,7 @@ protected:
     void getLineColumn(int position , int& startLine , int& startColumn);
 
 private:
-    QMultiHash<int,HotSpot*> _hotspots;
+    QMultiHash<int, HotSpot*> _hotspots;
     QList<HotSpot*> _hotspotList;
 
     const QList<int>* _linePositions;
@@ -236,8 +226,8 @@ protected:
      * Called when a match for the regular expression is encountered.  Subclasses should reimplement this
      * to return custom hotspot types
      */
-    virtual RegExpFilter::HotSpot* newHotSpot(int startLine,int startColumn,
-                                    int endLine,int endColumn);
+    virtual RegExpFilter::HotSpot* newHotSpot(int startLine, int startColumn,
+            int endLine, int endColumn);
 
 private:
     QRegExp _searchText;
@@ -256,7 +246,7 @@ public:
     class HotSpot : public RegExpFilter::HotSpot
     {
     public:
-        HotSpot(int startLine,int startColumn,int endLine,int endColumn);
+        HotSpot(int startLine, int startColumn, int endLine, int endColumn);
         virtual ~HotSpot();
 
         virtual QList<QAction*> actions();
@@ -267,10 +257,8 @@ public:
          */
         virtual void activate(QObject* object = 0);
 
-        virtual QString tooltip() const;
     private:
-        enum UrlType
-        {
+        enum UrlType {
             StandardUrl,
             Email,
             Unknown
@@ -283,22 +271,21 @@ public:
     UrlFilter();
 
 protected:
-    virtual RegExpFilter::HotSpot* newHotSpot(int,int,int,int);
+    virtual RegExpFilter::HotSpot* newHotSpot(int, int, int, int);
 
 private:
-
     static const QRegExp FullUrlRegExp;
     static const QRegExp EmailAddressRegExp;
 
     // combined OR of FullUrlRegExp and EmailAddressRegExp
-    static const QRegExp CompleteUrlRegExp; 
+    static const QRegExp CompleteUrlRegExp;
 };
 
 class FilterObject : public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    FilterObject(Filter::HotSpot* filter) : _filter(filter) {}
+    explicit FilterObject(Filter::HotSpot* filter) : _filter(filter) {}
 private slots:
     void activated();
 private:
@@ -344,7 +331,7 @@ public:
     void process();
 
     /** Sets the buffer for each filter in the chain to process. */
-    void setBuffer(const QString* buffer , const QList<int>* linePositions); 
+    void setBuffer(const QString* buffer , const QList<int>* linePositions);
 
     /** Returns the first hotspot which occurs at @p line, @p column or 0 if no hotspot was found */
     Filter::HotSpot* hotSpotAt(int line , int column) const;
@@ -352,7 +339,6 @@ public:
     QList<Filter::HotSpot*> hotSpots() const;
     /** Returns a list of all hotspots at the given line in all the chain's filters */
     QList<Filter::HotSpot> hotSpotsAtLine(int line) const;
-
 };
 
 /** A filter chain which processes character images from terminal displays */
@@ -371,12 +357,11 @@ public:
      * @param lineProperties The line properties to set for image
      */
     void setImage(const Character* const image , int lines , int columns,
-                  const QVector<LineProperty>& lineProperties);  
+                  const QVector<LineProperty>& lineProperties);
 
 private:
     QString* _buffer;
     QList<int>* _linePositions;
 };
-
 }
 #endif //FILTER_H
