@@ -47,7 +47,7 @@ class ViewProperties;
  */
 class Part : public KParts::ReadOnlyPart , public TerminalInterfaceV2
 {
-Q_OBJECT
+    Q_OBJECT
     Q_INTERFACES(TerminalInterface TerminalInterfaceV2)
 public:
     /** Constructs a new Konsole part with the specified parent. */
@@ -55,12 +55,12 @@ public:
     virtual ~Part();
 
     /** Reimplemented from TerminalInterface. */
-    virtual void startProgram( const QString& program,
-                               const QStringList& arguments );
+    virtual void startProgram(const QString& program,
+                              const QStringList& arguments);
     /** Reimplemented from TerminalInterface. */
-    virtual void showShellInDir( const QString& dir );
+    virtual void showShellInDir(const QString& dir);
     /** Reimplemented from TerminalInterface. */
-    virtual void sendInput( const QString& text );
+    virtual void sendInput(const QString& text);
 
     /** Reimplemented from TerminalInterfaceV2. */
     virtual int terminalProcessId();
@@ -72,6 +72,23 @@ public:
     virtual QString foregroundProcessName();
 
 public slots:
+    /**
+     * creates and run a session using the specified profile and directory
+     *
+     * @param profileName Specifies the  name of the profile to create session
+     * @param directory specifies The initial working directory of the created session
+     *
+     * This is highly experimental. Do not use it at the moment
+     */
+    void createSession(const QString& profileName = QString(), const QString& directory = QString());
+
+    /**
+     * Returns a list of names of all available proifles
+     *
+     * This is highly experimental. Do not use it at the moment
+     */
+    QStringList profileNameList() const;
+
     /**
      * Shows the dialog used to manage profiles in Konsole.  The dialog
      * will be non-modal and will delete itself when it is closed.
@@ -120,14 +137,21 @@ public slots:
      * */
     void setMonitorSilenceEnabled(bool enabled);
 
-     /**
-     * Toggles monitoring for activity in the active session. If activity is detected,
-     * the activityDetected() signal is emitted.
-     *
-     * @param enabled Whether to enable or disable monitoring for activity.
-     * */
+    /**
+    * Toggles monitoring for activity in the active session. If activity is detected,
+    * the activityDetected() signal is emitted.
+    *
+    * @param enabled Whether to enable or disable monitoring for activity.
+    * */
     void setMonitorActivityEnabled(bool enabled);
 
+    /**
+    * Returns the current working directory of the active session
+    *
+    * TODO: this should better be moved into TerminalInterfaceV2.
+    */
+    QString currentWorkingDirectory() const;
+
 signals:
     /**
      * Emitted when the key sequence for a shortcut, which is also a valid terminal key sequence,
@@ -160,34 +184,35 @@ signals:
      */
     void activityDetected();
 
+    /**
+     * Emitted when the current working directory of the active session has changed.
+     */
+    void currentDirectoryChanged(const QString& dir);
+
 protected:
     /** Reimplemented from KParts::PartBase. */
     virtual bool openFile();
-    virtual bool openUrl(const KUrl & url);
+    virtual bool openUrl(const KUrl& url);
 
 private slots:
-    // creates a new session using the specified profile.
-    // call the run() method on the returned Session instance to begin the session
-    Session* createSession(const Profile::Ptr profile = Profile::Ptr());
     void activeViewChanged(SessionController* controller);
     void activeViewTitleChanged(ViewProperties* properties);
     void showManageProfilesDialog();
     void terminalExited();
     void newTab();
-    void overrideTerminalShortcut(QKeyEvent*,bool& override);
+    void overrideTerminalShortcut(QKeyEvent*, bool& override);
     void sessionStateChanged(int state);
 
 private:
     Session* activeSession() const;
-    void setupActionsForSession(SessionController* session);
     void createGlobalActions();
+    void setupActionsForSession(SessionController*);
 
 private:
     ViewManager* _viewManager;
     SessionController* _pluggedController;
     QAction* _manageProfilesAction;
 };
-
 }
 
 #endif // PART_H
